==> libreoffice-still-sdk-5.1.6-5-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/files_6.js <==
var searchData=
[
  ['galleryitem_2eidl',['GalleryItem.idl',['../GalleryItem_8idl.html',1,'']]],
  ['galleryitemtype_2eidl',['GalleryItemType.idl',['../GalleryItemType_8idl.html',1,'']]],
  ['gallerytheme_2eidl',['GalleryTheme.idl',['../GalleryTheme_8idl.html',1,'']]],
  ['gallerythemeprovider_2eidl',['GalleryThemeProvider.idl',['../GalleryThemeProvider_8idl.html',1,'']]],
  ['generalfunction_2eidl',['GeneralFunction.idl',['../GeneralFunction_8idl.html',1,'']]],
  ['generated_5fidl_5fchapter_5frefs_2eidl',['generated_idl_chapter_refs.idl',['../generated__idl__chapter__refs_8idl.html',1,'']]],
  ['genericclipboard_2eidl',['GenericClipboard.idl',['../GenericClipboard_8idl.html',1,'']]],
  ['genericdrawingdocument_2eidl',['GenericDrawingDocument.idl',['../GenericDrawingDocument_8idl.html',1,'']]],
  ['genericdrawpage_2eidl',['GenericDrawPage.idl',['../GenericDrawPage_8idl.html',1,'']]],
  ['genericpropertyhandler_2eidl',['GenericPropertyHandler.idl',['../GenericPropertyHandler_8idl.html',1,'']]],
  ['generictextdocument_2eidl',['GenericTextDocument.idl',['../GenericTextDocument_8idl.html',1,'']]],
  ['getdirectpropertytolerantresult_2eidl',['GetDirectPropertyTolerantResult.idl',['../GetDirectPropertyTolerantResult_8idl.html',1,'']]],
  ['getexpression_2eidl',['GetExpression.idl',['../GetExpression_8idl.html',1,'']]],
  ['getpropertytolerantresult_2eidl',['GetPropertyTolerantResult.idl',['../GetPropertyTolerantResult_8idl.html',1,'']]],
  ['getreference_2eidl',['GetReference.idl',['../GetReference_8idl.html',1,'']]],
  ['giocontentprovider_2eidl',['GIOContentProvider.idl',['../GIOContentProvider_8idl.html',1,'']]],
  ['globalacceleratorconfiguration_2eidl',['GlobalAcceleratorConfiguration.idl',['../GlobalAcceleratorConfiguration_8idl.html',1,'']]],
  ['globaldocument_2eidl',['GlobalDocument.idl',['../GlobalDocument_8idl.html',1,'']]],
  ['globaleventbroadcaster_2eidl',['GlobalEventBroadcaster.idl',['../GlobalEventBroadcaster_8idl.html',1,'']]],
  ['globalsettings_2eidl',['GlobalSettings.idl',['../GlobalSettings_8idl.html',1,'']]],
  ['globalsheetsettings_2eidl',['GlobalSheetSettings.idl',['../GlobalSheetSettings_8idl.html',1,'']]],
  ['globaltransfercommandargument_2eidl',['GlobalTransferCommandArgument.idl',['../GlobalTransferCommandArgument_8idl.html',1,'']]],
  ['globaltransfercommandargument2_2eidl',['GlobalTransferCommandArgument2.idl',['../GlobalTransferCommandArgument2_8idl.html',1,'']]],
  ['gluepoint_2eidl',['GluePoint.idl',['../GluePoint_8idl.html',1,'']]],
  ['gluepoint2_2eidl',['GluePoint2.idl',['../GluePoint2_8idl.html',1,'']]],
  ['gnomevfscontentprovider_2eidl',['GnomeVFSContentProvider.idl',['../GnomeVFSContentProvider_8idl.html',1,'']]],
  ['gnomevfsdocumentcontent_2eidl',['GnomeVFSDocumentContent.idl',['../GnomeVFSDocumentContent_8idl.html',1,'']]],
  ['gnomevfsfoldercontent_2eidl',['GnomeVFSFolderContent.idl',['../GnomeVFSFolderContent_8idl.html',1,'']]],
  ['goalresult_2eidl',['GoalResult.idl',['../GoalResult_8idl.html',1,'']]],
  ['gradient_2eidl',['Gradient.idl',['../Gradient_8idl.html',1,'']]],
  ['gradientstyle_2eidl',['GradientStyle.idl',['../GradientStyle_8idl.html',1,'']]],
  ['gradienttable_2eidl',['GradientTable.idl',['../GradientTable_8idl.html',1,'']]],
  ['graphic_2eidl',['Graphic.idl',['../Graphic_8idl.html',1,'']]],
  ['graphiccolormode_2eidl',['GraphicColorMode.idl',['../GraphicColorMode_8idl.html',1,'']]],
  ['graphiccrop_2eidl',['GraphicCrop.idl',['../GraphicCrop_8idl.html',1,'']]],
  ['graphicdescriptor_2eidl',['GraphicDescriptor.idl',['../GraphicDescriptor_8idl.html',1,'']]],
  ['graphicexportfilter_2eidl',['GraphicExportFilter.idl',['../GraphicExportFilter_8idl.html',1,'']]],
  ['graphicfilterrequest_2eidl',['GraphicFilterRequest.idl',['../GraphicFilterRequest_8idl.html',1,'']]],
  ['graphiclocation_2eidl',['GraphicLocation.idl',['../GraphicLocation_8idl.html',1,'']]],
  ['graphicobject_2eidl',['GraphicObject.idl',['../GraphicObject_8idl.html',1,'']]],
  ['graphicobjectcount_2eidl',['GraphicObjectCount.idl',['../GraphicObjectCount_8idl.html',1,'']]],
  ['graphicobjectresolver_2eidl',['GraphicObjectResolver.idl',['../GraphicObjectResolver_8idl.html',1,'']]],
  ['graphicobjectshape_2eidl',['GraphicObjectShape.idl',['../drawing_2GraphicObjectShape_8idl.html',1,'']]],
  ['graphicobjectshape_2eidl',['GraphicObjectShape.idl',['../presentation_2GraphicObjectShape_8idl.html',1,'']]],
  ['graphicprovider_2eidl',['GraphicProvider.idl',['../GraphicProvider_8idl.html',1,'']]],
  ['graphicrasterizer_2eidl',['GraphicRasterizer.idl',['../GraphicRasterizer_8idl.html',1,'']]],
  ['graphicrenderervcl_2eidl',['GraphicRendererVCL.idl',['../GraphicRendererVCL_8idl.html',1,'']]],
  ['graphictype_2eidl',['GraphicType.idl',['../GraphicType_8idl.html',1,'']]],
  ['gridcolumn_2eidl',['GridColumn.idl',['../GridColumn_8idl.html',1,'']]],
  ['gridcolumnevent_2eidl',['GridColumnEvent.idl',['../GridColumnEvent_8idl.html',1,'']]],
  ['gridcontrol_2eidl',['GridControl.idl',['../control_2GridControl_8idl.html',1,'']]],
  ['gridcontrol_2eidl',['GridControl.idl',['../component_2GridControl_8idl.html',1,'']]],
  ['griddataevent_2eidl',['GridDataEvent.idl',['../GridDataEvent_8idl.html',1,'']]],
  ['gridinvaliddataexception_2eidl',['GridInvalidDataException.idl',['../GridInvalidDataException_8idl.html',1,'']]],
  ['gridinvalidmodelexception_2eidl',['GridInvalidModelException.idl',['../GridInvalidModelException_8idl.html',1,'']]],
  ['gridproperties_2eidl',['GridProperties.idl',['../GridProperties_8idl.html',1,'']]],
  ['gridselectionevent_2eidl',['GridSelectionEvent.idl',['../GridSelectionEvent_8idl.html',1,'']]],
  ['group_2eidl',['Group.idl',['../sdbcx_2Group_8idl.html',1,'']]],
  ['group_2eidl',['Group.idl',['../report_2Group_8idl.html',1,'']]],
  ['groupaccess_2eidl',['GroupAccess.idl',['../GroupAccess_8idl.html',1,'']]],
  ['groupbox_2eidl',['GroupBox.idl',['../component_2GroupBox_8idl.html',1,'']]],
  ['groupbox_2eidl',['GroupBox.idl',['../control_2GroupBox_8idl.html',1,'']]],
  ['groupdescriptor_2eidl',['GroupDescriptor.idl',['../GroupDescriptor_8idl.html',1,'']]],
  ['groupelement_2eidl',['GroupElement.idl',['../GroupElement_8idl.html',1,'']]],
  ['groupkeeptogether_2eidl',['GroupKeepTogether.idl',['../GroupKeepTogether_8idl.html',1,'']]],
  ['groupon_2eidl',['GroupOn.idl',['../GroupOn_8idl.html',1,'']]],
  ['groups_2eidl',['Groups.idl',['../Groups_8idl.html',1,'']]],
  ['groupshape_2eidl',['GroupShape.idl',['../GroupShape_8idl.html',1,'']]],
  ['groupupdate_2eidl',['GroupUpdate.idl',['../GroupUpdate_8idl.html',1,'']]]
];

==> libreoffice-still-sdk-5.3.6-1-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/files_6.js <==
var searchData=
[
  ['galleryitem_2eidl',['GalleryItem.idl',['../GalleryItem_8idl.html',1,'']]],
  ['galleryitemtype_2eidl',['GalleryItemType.idl',['../GalleryItemType_8idl.html',1,'']]],
  ['gallerytheme_2eidl',['GalleryTheme.idl',['../GalleryTheme_8idl.html',1,'']]],
  ['gallerythemeprovider_2eidl',['GalleryThemeProvider.idl',['../GalleryThemeProvider_8idl.html',1,'']]],
  ['generalfunction_2eidl',['GeneralFunction.idl',['../GeneralFunction_8idl.html',1,'']]],
  ['generalfunction2_2eidl',['GeneralFunction2.idl',['../GeneralFunction2_8idl.html',1,'']]],
  ['generated_5fidl_5fchapter_5frefs_2eidl',['generated_idl_chapter_refs.idl',['../generated__idl__chapter__refs_8idl.html',1,'']]],
  ['genericclipboard_2eidl',['GenericClipboard.idl',['../GenericClipboard_8idl.html',1,'']]],
  ['genericdrawingdocument_2eidl',['GenericDrawingDocument.idl',['../GenericDrawingDocument_8idl.html',1,'']]],
  ['genericdrawpage_2eidl',['GenericDrawPage.idl',['../GenericDrawPage_8idl.html',1,'']]],
  ['genericpropertyhandler_2eidl',['GenericPropertyHandler.idl',['../GenericPropertyHandler_8idl.html',1,'']]],
  ['generictextdocument_2eidl',['GenericTextDocument.idl',['../GenericTextDocument_8idl.html',1,'']]],
  ['getdirectpropertytolerantresult_2eidl',['GetDirectPropertyTolerantResult.idl',['../GetDirectPropertyTolerantResult_8idl.html',1,'']]],
  ['getexpression_2eidl',['GetExpression.idl',['../GetExpression_8idl.html',1,'']]],
  ['getpropertytolerantresult_2eidl',['GetPropertyTolerantResult.idl',['../GetPropertyTolerantResult_8idl.html',1,'']]],
  ['getreference_2eidl',['GetReference.idl',['../GetReference_8idl.html',1,'']]],
  ['giocontentprovider_2eidl',['GIOContentProvider.idl',['../GIOContentProvider_8idl.html',1,'']]],
  ['globalacceleratorconfiguration_2eidl',['GlobalAcceleratorConfiguration.idl',['../GlobalAcceleratorConfiguration_8idl.html',1,'']]],
  ['globaldocument_2eidl',['GlobalDocument.idl',['../GlobalDocument_8idl.html',1,'']]],
  ['globaleventbroadcaster_2eidl',['GlobalEventBroadcaster.idl',['../GlobalEventBroadcaster_8idl.html',1,'']]],
  ['globalsettings_2eidl',['GlobalSettings.idl',['../GlobalSettings_8idl.html',1,'']]],
  ['globalsheetsettings_2eidl',['GlobalSheetSettings.idl',['../GlobalSheetSettings_8idl.html',1,'']]],
  ['globaltransfercommandargument_2eidl',['GlobalTransferCommandArgument.idl',['../GlobalTransferCommandArgument_8idl.html',1,'']]],
  ['globaltransfercommandargument2_2eidl',['GlobalTransferCommandArgument2.idl',['../GlobalTransferCommandArgument2_8idl.html',1,'']]],
  ['gluepoint_2eidl',['GluePoint.idl',['../GluePoint_8idl.html',1,'']]],
  ['gluepoint2_2eidl',['GluePoint2.idl',['../GluePoint2_8idl.html',1,'']]],
  ['gnomevfscontentprovider_2eidl',['GnomeVFSContentProvider.idl',['../GnomeVFSContentProvider_8idl.html',1,'']]],
  ['gnomevfsdocumentcontent_2eidl',['GnomeVFSDocumentContent.idl',['../GnomeVFSDocumentContent_8idl.html',1,'']]],
  ['gnomevfsfoldercontent_2eidl',['GnomeVFSFolderContent.idl',['../GnomeVFSFolderContent_8idl.html',1,'']]],
  ['goalresult_2eidl',['GoalResult.idl',['../GoalResult_8idl.html',1,'']]],
  ['gradient_2eidl',['Gradient.idl',['../Gradient_8idl.html',1,'']]],
  ['gradientstyle_2eidl',['GradientStyle.idl',['../GradientStyle_8idl.html',1,'']]],
  ['gradienttable_2eidl',['GradientTable.idl',['../GradientTable_8idl.html',1,'']]],
  ['graphic_2eidl',['Graphic.idl',['../Graphic_8idl.html',1,'']]],
  ['graphiccolormode_2eidl',['GraphicColorMode.idl',['../GraphicColorMode_8idl.html',1,'']]],
  ['graphiccrop_2eidl',['GraphicCrop.idl',['../GraphicCrop_8idl.html',1,'']]],
  ['graphicdescriptor_2eidl',['GraphicDescriptor.idl',['../GraphicDescriptor_8idl.html',1,'']]],
  ['graphicexportfilter_2eidl',['GraphicExportFilter.idl',['../GraphicExportFilter_8idl.html',1,'']]],
  ['graphicfilterrequest_2eidl',['GraphicFilterRequest.idl',['../GraphicFilterRequest_8idl.html',1,'']]],
  ['graphiclocation_2eidl',['GraphicLocation.idl',['../GraphicLocation_8idl.html',1,'']]],
  ['graphicobject_2eidl',['GraphicObject.idl',['../GraphicObject_8idl.html',1,'']]],
  ['graphicobjectcount_2eidl',['GraphicObjectCount.idl',['../GraphicObjectCount_8idl.html',1,'']]],
  ['graphicobjectresolver_2eidl',['GraphicObjectResolver.idl',['../GraphicObjectResolver_8idl.html',1,'']]],
  ['graphicobjectshape_2eidl',['GraphicObjectShape.idl',['../drawing_2GraphicObjectShape_8idl.html',1,'(Global Namespace)'],['../presentation_2GraphicObjectShape_8idl.html',1,'(Global Namespace)']]],
  ['graphicprovider_2eidl',['GraphicProvider.idl',['../GraphicProvider_8idl.html',1,'']]],
  ['graphicrasterizer_2eidl',['GraphicRasterizer.idl',['../GraphicRasterizer_8idl.html',1,'']]],
  ['graphicrenderervcl_2eidl',['GraphicRendererVCL.idl',['../GraphicRendererVCL_8idl.html',1,'']]],
  ['graphictype_2eidl',['GraphicType.idl',['../GraphicType_8idl.html',1,'']]],
  ['gridcolumn_2eidl',['GridColumn.idl',['../GridColumn_8idl.html',1,'']]],
  ['gridcolumnevent_2eidl',['GridColumnEvent.idl',['../GridColumnEvent_8idl.html',1,'']]],
  ['gridcontrol_2eidl',['GridControl.idl',['../component_2GridControl_8idl.html',1,'(Global Namespace)'],['../control_2GridControl_8idl.html',1,'(Global Namespace)']]],
  ['griddataevent_2eidl',['GridDataEvent.idl',['../GridDataEvent_8idl.html',1,'']]],
  ['gridinvaliddataexception_2eidl',['GridInvalidDataException.idl',['../GridInvalidDataException_8idl.html',1,'']]],
  ['gridinvalidmodelexception_2eidl',['GridInvalidModelException.idl',['../GridInvalidModelException_8idl.html',1,'']]],
  ['gridproperties_2eidl',['GridProperties.idl',['../GridProperties_8idl.html',1,'']]],
  ['gridselectionevent_2eidl',['GridSelectionEvent.idl',['../GridSelectionEvent_8idl.html',1,'']]],
  ['group_2eidl',['Group.idl',['../report_2Group_8idl.html',1,'(Global Namespace)'],['../sdbcx_2Group_8idl.html',1,'(Global Namespace)']]],
  ['groupaccess_2eidl',['GroupAccess.idl',['../GroupAccess_8idl.html',1,'']]],
  ['groupbox_2eidl',['GroupBox.idl',['../component_2GroupBox_8idl.html',1,'(Global Namespace)'],['../control_2GroupBox_8idl.html',1,'(Global Namespace)']]],
  ['groupdescriptor_2eidl',['GroupDescriptor.idl',['../GroupDescriptor_8idl.html',1,'']]],
  ['groupelement_2eidl',['GroupElement.idl',['../GroupElement_8idl.html',1,'']]],
  ['groupkeeptogether_2eidl',['GroupKeepTogether.idl',['../GroupKeepTogether_8idl.html',1,'']]],
  ['groupon_2eidl',['GroupOn.idl',['../GroupOn_8idl.html',1,'']]],
  ['groups_2eidl',['Groups.idl',['../Groups_8idl.html',1,'']]],
  ['groupshape_2eidl',['GroupShape.idl',['../GroupShape_8idl.html',1,'']]],
  ['groupupdate_2eidl',['GroupUpdate.idl',['../GroupUpdate_8idl.html',1,'']]]
];
